@@ -34,7 +34,7 @@ from gradio.components import (
     get_component_instance,
 )
 from gradio.events import Changeable, Streamable
-from gradio.external import load_from_pipeline, load_interface  # type: ignore
+from gradio.external import load_from_pipeline  # type: ignore
 from gradio.flagging import CSVLogger, FlaggingCallback  # type: ignore
 from gradio.layouts import Column, Row, TabItem, Tabs
 from gradio.process_examples import cache_interface_examples, load_from_cache
@@ -87,11 +87,7 @@ class Interface(Blocks):
         Returns:
         (gradio.Interface): a Gradio Interface object for the given model
         """
-        interface_info = load_interface(name, src, api_key, alias)
-        kwargs = dict(interface_info, **kwargs)
-        interface = cls(**kwargs)
-        interface.api_mode = True  # So interface doesn't run pre/postprocess.
-        return interface
+        return super().load(name=name, src=src, api_key=api_key, alias=alias, **kwargs)
 
     @classmethod
     def from_pipeline(cls, pipeline: transformers.Pipeline, **kwargs) -> Interface:
@@ -251,10 +247,7 @@ class Interface(Blocks):
         self.predict_durations = [[0, 0]] * len(fn)
         self.function_names = [func.__name__ for func in fn]
         self.__name__ = ", ".join(self.function_names)
-
         self.live = live
-        self.flag_hash = random.getrandbits(32)
-
         self.title = title
 
         CLEANER = re.compile("<.*?>")
@@ -468,14 +461,14 @@ class Interface(Blocks):
                                 self.InterfaceTypes.STANDARD,
                                 self.InterfaceTypes.INPUT_ONLY,
                             ]:
-                                clear_btn = Button("Clear", variant="secondary")
+                                clear_btn = Button("Clear")
                                 if not self.live:
-                                    submit_btn = Button("Submit")
+                                    submit_btn = Button("Submit", variant="primary")
                             elif self.interface_type == self.InterfaceTypes.UNIFIED:
-                                clear_btn = Button("Clear", variant="secondary")
-                                submit_btn = Button("Submit")
+                                clear_btn = Button("Clear")
+                                submit_btn = Button("Submit", variant="primary")
                                 if self.allow_flagging == "manual":
-                                    flag_btn = Button("Flag", variant="secondary")
+                                    flag_btn = Button("Flag")
 
                 if self.interface_type in [
                     self.InterfaceTypes.STANDARD,
@@ -488,14 +481,12 @@ class Interface(Blocks):
                             component.render()
                         with Row().style(mobile_collapse=False):
                             if self.interface_type == self.InterfaceTypes.OUTPUT_ONLY:
-                                clear_btn = Button("Clear", variant="secondary")
-                                submit_btn = Button("Generate")
+                                clear_btn = Button("Clear")
+                                submit_btn = Button("Generate", variant="primary")
                             if self.allow_flagging == "manual":
-                                flag_btn = Button("Flag", variant="secondary")
+                                flag_btn = Button("Flag")
                             if self.interpretation:
-                                interpretation_btn = Button(
-                                    "Interpret", variant="secondary"
-                                )
+                                interpretation_btn = Button("Interpret")
             submit_fn = (
                 lambda *args: self.run_prediction(args)[0]
                 if len(self.output_components) == 1
