@@ -3,7 +3,7 @@ import math
 
 import numpy as np
 
-from gradio.outputs import Label, Textbox
+from gradio.components import Label, Number, Textbox
 
 
 def run_interpret(interface, raw_input):
@@ -153,7 +153,7 @@ def run_interpret(interface, raw_input):
                 scores.append(None)
                 alternative_outputs.append([])
             else:
-                raise ValueError("Uknown intepretation method: {}".format(interp))
+                raise ValueError("Unknown intepretation method: {}".format(interp))
         return scores, alternative_outputs
     else:  # custom interpretation function
         processed_input = [
@@ -161,12 +161,7 @@ def run_interpret(interface, raw_input):
             for i, input_component in enumerate(interface.input_components)
         ]
         interpreter = interface.interpretation
-        if interface.capture_session and interface.session is not None:
-            graph, sess = interface.session
-            with graph.as_default(), sess.as_default():
-                interpretation = interpreter(*processed_input)
-        else:
-            interpretation = interpreter(*processed_input)
+        interpretation = interpreter(*processed_input)
         if len(raw_input) == 1:
             interpretation = [interpretation]
         return interpretation, []
@@ -198,7 +193,7 @@ def quantify_difference_in_label(interface, original_output, perturbed_output):
             score = diff(original_label, perturbed_label)
         return score
 
-    elif isinstance(output_component, Textbox):
+    elif isinstance(output_component, Number):
         score = diff(post_original_output, post_perturbed_output)
         return score
 
